@@ -1,7 +1,7 @@
 import datetime
 import time
 import os
-from .scala import *
+from .scalascript import *
 from .file import *
 
 PICTURE_FORMATS_DICT = {
@@ -9,6 +9,7 @@ PICTURE_FORMATS_DICT = {
     'square':       "http://narrowcasting.fimpweb.nl/imageresize.php?width=512&url=",
 }
 
+
 def get_datetime_object(item):
     unparsedpubdate = item.find('pubDate').text
 
@@ -38,7 +39,7 @@ def install_picture_content_wrap(picture_format, picture_formats, subdirectory,
         return False
 
     install_content(
-        media_path, subfolder=subdirectory, autostart=True)
+        media_path, subdirectory)
 
     media_filename = media_path.split('\\').pop()
 
