@@ -1,7 +1,7 @@
 import datetime
 import time
 import os
-from .scala import *
+from .scalascript import *
 from .file import download_media
 
 PICTURE_FORMATS_DICT = {
@@ -36,7 +36,7 @@ def install_picture_content_wrap(picture_format, picture_formats, subdirectory,
     media_path = download_media(
         PICTURE_FORMATS_DICT[picture_format] + media_link, subdirectory, tempfolder)
 
-    install_content(media_path, subdirectory, True)
+    install_content(media_path, subdirectory)
 
     media_filename = media_path.split('\\').pop()
 
